# API Reference

Complete API documentation for RAGLint.

```{toctree}
:maxdepth: 2

core
metrics
plugins
llm
config
tracking
integrations
benchmarks
```

## Core Components

- {doc}`core` - Main analyzer and result classes
- {doc}`metrics` - Built-in metrics (faithfulness, semantic, context)
- {doc}`plugins` - Plugin system and built-in plugins
- {doc}`llm` - LLM providers (OpenAI, Ollama, Mock)
- {doc}`config` - Configuration management
- {doc}`tracking` - Cost and latency tracking
- {doc}`integrations` - LangChain and other integrations
- {doc}`benchmarks` - SQUAD and benchmark registry
